==> centreon-web-24.04.20.tar.gz: centreon-web-24.04.20/www/front_src/src/ApiTokens/translatedLabels.ts <==
export const labelSearch = 'Search';
export const labelCreateNewToken = 'Create new token';
export const labelRevoked = 'Revoked';
export const labelActive = 'Active';
export const labelSearchOptions = 'Filter options';
export const labelDelete = 'Delete';
export const labelApiToken = 'API token';
export const labelGenerateNewToken = 'Generate new token';
export const labelClose = 'Close';
export const labelName = 'Name';
export const labelDuration = 'Duration';
export const labelUser = 'User';
export const labelTokenCopiedToTheClipboard = 'Token copied to the clipboard';
export const labelTokenCouldNotBeCopied = 'Token could not be copied';
export const labelInvalidDateCreationToken =
  'The end date must be greater than the current date by at least one day';
export const labelFieldRequired = 'This field is required';
export const labelToken = 'Token';
export const labelOk = 'Ok';
export const labelCancel = 'Cancel';
export const labelTokenCreated = 'Token has been created';
export const labelSecurityToken =
  'For security reasons, the token can only be displayed once. Store it carefully.';
export const labelCreator = 'Creator';
export const labelMsgConfirmationDeletionToken =
  'You are about to delete the token <b> {{tokenName}}</b>. This action <br> cannot be undone. If you proceed, all requests made using this token will be <br> rejected. Do you want to delete the token?';
export const labelDeleteToken = 'Delete token';
export const labelTokenDeletedSuccessfully = 'Token deleted successfully';
export const labelActiveToken = 'Active tokens';
export const labelRevokedToken = 'Disabled tokens';
export const labelStatus = 'Status';
export const labelCreationDate = 'Creation date';
export const labelExpirationDate = 'Expiration date';
export const labelClear = 'Clear';
export const labelUntil = 'Until';

==> centreon-web-24.04.25.tar.gz: centreon-web-24.04.25/www/front_src/src/ApiTokens/translatedLabels.ts <==
export const labelSearch = 'Search';
export const labelCreateNewToken = 'Create new token';
export const labelRevoked = 'Revoked';
export const labelActive = 'Active';
export const labelSearchOptions = 'Filter options';
export const labelDelete = 'Delete';
export const labelApiToken = 'API token';
export const labelGenerateNewToken = 'Generate new token';
export const labelClose = 'Close';
export const labelName = 'Name';
export const labelDuration = 'Duration';
export const labelUser = 'User';
export const labelTokenCopiedToTheClipboard = 'Token copied to the clipboard';
export const labelTokenCouldNotBeCopied = 'Token could not be copied';
export const labelInvalidDateCreationToken =
  'The end date must be greater than the current date by at least one day';
export const labelFieldRequired = 'This field is required';
export const labelToken = 'Token';
export const labelOk = 'Ok';
export const labelCancel = 'Cancel';
export const labelTokenCreated = 'Token has been created';
export const labelSecurityToken =
  'For security reasons, the token can only be displayed once. Store it carefully.';
export const labelCreator = 'Creator';
export const labelMsgConfirmationDeletionToken =
  'You are about to delete the token <b> {{tokenName}}</b>. This action <br> cannot be undone. If you proceed, all requests made using this token will be <br> rejected. Do you want to delete the token?';
export const labelDeleteToken = 'Delete token';
export const labelTokenDeletedSuccessfully = 'Token deleted successfully';
export const labelActiveToken = 'Active tokens';
export const labelRevokedToken = 'Disabled tokens';
export const labelStatus = 'Status';
export const labelCreationDate = 'Creation date';
export const labelExpirationDate = 'Expiration date';
export const labelClear = 'Clear';
export const labelUntil = 'Until';

export const labelDisabled = 'Disabled';
export const labelEnabled = 'Enabled';
export const labelFilters = 'Filters';

export const labelRefresh = 'Refresh';
